@@ -27,11 +27,14 @@ data_sources = {
             "is_away",
             "is_start",
             "g_nbr",
+            "receiving_tgt",
             "receiving_rec",
             "receiving_yds",
             "receiving_td",
+            "rushing_att",
             "rushing_yds",
             "rushing_td",
+            "passing_att",
             "passing_cmp",
             "passing_yds",
             "passing_td",
@@ -39,6 +42,7 @@ data_sources = {
             "passing_int",
             "scoring_2pm",
             "punt_returns_td",
+            "off_snaps_pct",
         ],
         "is_required": False,
         "is_forward_looking": False,
